@@ -5,9 +5,9 @@
 # This is a deluser script for NetBSD systems whose userdel(8) doesn't
 # accept "$" in the username.
 
-awkprog="/bin/awk"
+awkprog="/usr/pkg/bin/nawk"
 mktempprog="/usr/bin/mktemp"
-pwdmkdbprog="pwd_mkdb"
+pwdmkdbprog=""
 rmprog="/bin/rm"
 
 progname=deluser
